STb_compare_lfo()
STb_compare_lfo.RdCompare two or more objects returned by STb_lfo() using leave-future-out
expected log predictive density. The model with the highest total elpd_lfo
is treated as the reference model. Differences are reported relative to that model.
Arguments
- ...
Two or more LFO objects returned by
STb_lfo().- model_names
Optional character vector of model names. If
NULL, names are taken from...when available, otherwise generic names are used.- n_obs
Optional integer giving the number of pointwise observations to use when computing standard errors. If
NULL, the number of complete pointwise observations across models is used.- digits
Integer. Number of digits used for rounding the returned table. Defaults to
1.
Value
A data frame with columns:
elpd_diffDifference in total ELPD from the best model.
se_diffStandard error of the ELPD difference.
elpd_lfoTotal leave-future-out ELPD.
se_elpd_lfoStandard error of total leave-future-out ELPD.
lfoicLFO information criterion, computed as
-2 * elpd_lfo.se_lfoicStandard error of
lfoic.